@@ -1,10 +1,10 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2002-2010 Chris Liechti <cliechti@gmx.net>
-# All Rights Reserved.
-# Simplified BSD License (see LICENSE.txt for full text)
-
+# This file is part of https://github.com/zsquareplusc/python-msp430-tools
+# (C) 2002-2010 Chris Liechti <cliechti@gmx.net>
+#
+# SPDX-License-Identifier:    BSD-3-Clause
 """\
 Interface to GDB server suing a TCP/IP connection.
 
@@ -13,21 +13,32 @@ It can be used to talk to e.g. msp430-gdbproxy or mspdebug.
 
 from struct import pack, unpack
 import socket
+import sys
 import threading
-import Queue
+
+
+try:
+    import queue
+except ImportError:
+    import Queue as queue
+
 
 class GDBException(Exception):
     """Generic protocol errors"""
 
+
 class GDBRemoteTimeout(GDBException):
     """If target does not answer"""
 
+
 class GDBRemoteTooManyFailures(GDBException):
     """If target does not answer"""
 
+
 class GDBUnknownCommandError(GDBException):
     """If target does not know this command"""
 
+
 class GDBRemoteError(GDBException):
     """Target answered with 'E' (error) packet"""
     def __init__(self, errorcode, message):
@@ -38,17 +49,16 @@ class GDBRemoteError(GDBException):
         return self.errorcode
 
 
-
 HEXDIGITS = '0123456789abcdefABCDEF'
 IDLE, DATA, CRC1, CRC2 = ' ', '$', '1', '2'
 WAITING, SUCCESS, FAILURE = 0, 1, 2
 
 # breakpoint/watchpoint types:
-BRK_SOFTWARE            = 0
-BRK_HARDWARE            = 1
-BRK_WRITEWATCH          = 2
-BRK_READWATCH           = 3
-BRK_ACCESSWATCH         = 4
+BRK_SOFTWARE = 0
+BRK_HARDWARE = 1
+BRK_WRITEWATCH = 2
+BRK_READWATCH = 3
+BRK_ACCESSWATCH = 4
 
 STOP_SIGNAL = 'signal'
 STOP_THREAD = 'thread'
@@ -96,13 +106,16 @@ class ClientSocketConnector(threading.Thread):
             except socket.error:
                 break   # socket error -> terminate
             else:
-                if not text: break  # EOF -> terminate
+                if not text:
+                    break  # EOF -> terminate
                 self.handle_partial_data(text)
         self._alive = False
 
 
 # dummy decoder, not changing the message
-def identity(x): return x
+def identity(x):
+    return x
+
 
 # decoder for Stop Reply Packets
 def decodeStopReplyPackets(message):
@@ -123,12 +136,15 @@ def decodeStopReplyPackets(message):
     else:
         raise GDBException("unknown Stop Reply Packet")
 
+
 def hex2registers(message):
     return list(unpack('<HHHHHHHHHHHHHHHH', bytes(message).decode('hex')))
 
+
 def decodeRegister(message):
     return unpack('<H', bytes(message).decode('hex'))[0]
 
+
 def encodeRegister(value):
     return bytes(pack('<H', value).encode('hex'))
 
@@ -142,7 +158,7 @@ class GDBClient(ClientSocketConnector):
         self.errorcounter = 0   # count NACKS
         self.decoder = None
         self._lock = threading.Lock()
-        self.answer = Queue.Queue()
+        self.answer = queue.Queue()
 
     def handle_partial_data(self, data):
         #~ print data
@@ -186,26 +202,26 @@ class GDBClient(ClientSocketConnector):
         if packet == '':
             self.answer.put(GDBUnknownCommandError("Unknown command"))
         elif packet[0:1] == 'E':
-            errorcode = int(packet[1:],16)
+            errorcode = int(packet[1:], 16)
             self.answer.put(GDBRemoteError(errorcode, "Target responded with error code %d" % errorcode))
         elif packet[0:2] == 'OK':
             self.answer.put(None)
         elif packet[0:1] == 'o' or packet[0:1] == 'O':
             message = packet[1:]
             if len(message) & 1:
-                print "Odd length 'o' message - cutting off last character"     #XXX hack
+                sys.stderr.write("Odd length 'o' message - cutting off last character\n")  # XXX hack
                 message = message[:-1]
             self.output(message.decode('hex'))
         else:
             self.answer.put(packet.decode('hex'))
             #~ else:
-                #~ print "unwanted packet: %r" % packet            #XXX ugly
+                #~ print "unwanted packet: %r" % packet  # XXX ugly
 
     # --- callbacks ---
 
     def output(self, message):
         """called on 'o' (output) packages"""
-        print "REMOTE>", message
+        sys.stdout.write("REMOTE> {}\n".format(message))
 
     # --- commands ---
     def set_extended(self):
@@ -223,17 +239,17 @@ class GDBClient(ClientSocketConnector):
         expected answer Stop Reply Packets"""
         return self._remote_command('c%s' % (
                 startaddress is not None and '%x' % startaddress or ''
-            ), decoder=decodeStopReplyPackets, nowait=nowait, timeout=None
+               ), decoder=decodeStopReplyPackets, nowait=nowait, timeout=None
         )
 
     def cont_with_signal(self, signal, startaddress=None):
         """Csig;addr -- continue with signal
         expected answer Stop Reply Packets"""
-        return self._remote_command('C%02x%s' % (
+        return self._remote_command(
+            'C%02x%s' % (
                 signal,
-                startaddress is not None and ';%x' % startaddress or ''
-            ), decoder=decodeStopReplyPackets
-        )
+                startaddress is not None and ';%x' % startaddress or ''),
+            decoder=decodeStopReplyPackets)
 
     #~ def gdbDetach(self):
         #~ """D -- detach
@@ -290,22 +306,22 @@ class GDBClient(ClientSocketConnector):
         #~ no answer expected"""
         #~ return self._remote_command('Q%s=%s' % (querry, value))
 
-    def step(self, startaddress = None):
+    def step(self, startaddress=None):
         """saddr -- step
         expected answer Stop Reply Packets"""
-        return self._remote_command('s%s' % (
-                startaddress is not None and '%x' % startaddress or ''
-            ), decoder=decodeStopReplyPackets
-        )
+        return self._remote_command(
+            's%s' % (
+                startaddress is not None and '%x' % startaddress or ''),
+            decoder=decodeStopReplyPackets)
 
     def step_with_signal(self, signal, startaddress=None):
         """Ssig;addr -- step with signal
         expected answer Stop Reply Packets"""
-        return self._remote_command('S%02x%s' % (
+        return self._remote_command(
+            'S%02x%s' % (
                 signal,
-                startaddress is not None and ';%x' % startaddress or ''
-            ), decoder=decodeStopReplyPackets
-        )
+                startaddress is not None and ';%x' % startaddress or ''),
+            decoder=decodeStopReplyPackets)
 
     def write_memory_binary(self, startaddress, data):
         """maddr,data -- write memory
@@ -335,7 +351,6 @@ class GDBClient(ClientSocketConnector):
         expected answer 'OK' or 'Enn' or ''"""
         return self.query('Rcmd,%s' % bytes(command).encode('hex'), nowait=nowait)
 
-
     # ---
     def interrupt(self):
         """send Control+C.
@@ -365,7 +380,7 @@ class GDBClient(ClientSocketConnector):
                 raise ans
             else:
                 return decoder(ans)
-        except Queue.Empty:
+        except queue.Empty:
             raise GDBRemoteTimeout('no answer to command received within time')
         finally:
             self._lock.release()
